
API_URL = 'https://api.opinum.com:443/'
AUTHORIZATION_URL = 'https://identity.opinum.com/connect/token'
headers = {"Content-Type": "application/json",
           "Authorization": ""}


STANDARD_PUSH_DATA_URL = 'https://push.opinum.com/api/data/'

PATHS_TAGS = {'/accounts/{id}': 'Account', '/accounts': 'Account', '/accounts/{accountId}': 'Account',
              '/alerts': 'Alert', '/alerts/types': 'Alert', '/alerts/statuses': 'Alert', '/alerts/{alertId}': 'Alert',
              '/alerts/thresholds': 'Alert', '/alerts/aggregationTypes': 'Alert', '/alerts/notificationTypes': 'Alert',
              '/alerts/notificationTargets': 'Alert', '/alerts/notificationTypeTargetMapping': 'Alert',
              '/alerts/occurrences': 'AlertOccurrence', '/alerts/occurrences/statuses': 'AlertOccurrence',
              '/alerts/occurrences/status': 'AlertOccurrence', '/alerts/views': 'AlertView',
              '/alerts/views/{viewId}': 'AlertView', '/alerts/views/{id}': 'AlertView',
              '/extensions': 'CloudItemExtention', '/extensions/checkExtension': 'CloudItemExtention',
              '/dashboards': 'Dashboard', '/dashboards/{id}': 'Dashboard', '/dashboards/{id}/logo': 'Dashboard',
              '/dashboards/trendLineTypes': 'Dashboard', '/dashboards/email': 'Dashboard',
              '/dashboards/Image': 'Dashboard', '/data': 'Data', '/datapusher': 'DataPusher',
              '/dataquality/history/sources': 'DataQualityHistory',
              '/dataquality/history/variables': 'DataQualityHistory',
              '/dataquality/notifications/{sourceId}': 'DataQualityNotification',
              '/dataquality/notifications/{sourceId}/{notificationId}': 'DataQualityNotification',
              '/dataquality/overrides': 'DataQualityOverrides',
              '/dataquality/overrides/{overrideId}': 'DataQualityOverrides',
              '/dataquality/templates': 'DataQualityTemplates', '/errors/{code}': 'ErrorCode', '/errors': 'ErrorCode',
              '/events': 'Event', '/events/{id}': 'Event', '/events/eventTypes': 'Event',
              '/events/timeRangeTypes': 'Event', '/externallogin/loginproviders': 'ExternalLogin',
              '/externallogin/all/externalLogins': 'ExternalLogin',
              '/externallogin/user/externallogins': 'ExternalLogin',
              '/externallogin/account/externallogins': 'ExternalLogin',
              '/externallogin/user/externallogins/{userId}': 'ExternalLogin',
              '/externallogin/{type}/ftpCredientials': 'ExternalLogin',
              '/externallogin/{type}/basicAuth': 'ExternalLogin',
              '/externallogin/{type}/connectionString': 'ExternalLogin',
              '/externallogin/{type}/accountNameAndKey': 'ExternalLogin',
              '/externallogin/user/externallogin': 'ExternalLogin',
              '/externallogin/account/externallogin': 'ExternalLogin', '/fileTrigger/{id}': 'FileTrigger',
              '/fileTrigger/mappings': 'FileTrigger', '/fileTrigger/fileTypes': 'FileTrigger',
              '/fileTrigger/filterTypes': 'FileTrigger', '/fileTrigger/triggerTypes': 'FileTrigger',
              '/fileTrigger/generateToken': 'FileTrigger', '/fileTrigger/ingestionTypes': 'FileTrigger',
              '/fileTrigger/triggerCombinations': 'FileTrigger', '/fileTrigger': 'FileTrigger',
              '/fileTrigger/count': 'FileTrigger', '/form': 'Form', '/form/{id}': 'Form', '/form/fieldTypes': 'Form',
              '/form/entityTypes': 'Form', '/gateways': 'Gateway', '/gateways/{id}': 'Gateway',
              '/gateways/count': 'Gateway', '/groups/{groupId}': 'Group', '/groups': 'Group',
              '/groups/{groupId}/sites': 'Group', '/invitation/roles': 'Invitation', '/invitation': 'Invitation',
              '/invitation/sendBack': 'Invitation', '/invitation/isEmailUnique': 'Invitation',
              '/invitationNotification/{invitationId}': 'InvitationNotification', '/invoices': 'Invoice',
              '/invoices/types': 'Invoice', '/invoices/statuses': 'Invoice', '/invoices/{invoiceId}': 'Invoice',
              '/languages': 'Language', '/localization/{languageCode}': 'Localization',
              '/localization/label': 'Localization', '/localization': 'Localization', '/units': 'Metadata',
              '/sitetypes': 'Metadata', '/timezones': 'Metadata', '/aggregates': 'Metadata', '/unitFamily': 'Metadata',
              '/energyTypes': 'Metadata', '/granularity': 'Metadata', '/sourceTypes': 'Metadata',
              '/timePeriods': 'Metadata', '/energyUsages': 'Metadata', '/gatewayTypes': 'Metadata',
              '/quantityTypes': 'Metadata', '/variableTypes': 'Metadata',
              '/notificationMessageStatusHistory/{trackingId}': 'NotificationMessageStatusHistory',
              '/notificationMessageStatusHistory/Plivo': 'NotificationMessageStatusHistory',
              '/notificationMessageStatusHistory/Sendgrid': 'NotificationMessageStatusHistory',
              '/primaryConsumption/source/{sourceId}': 'PrimaryConsumption',
              '/primaryConsumption/{id}': 'PrimaryConsumption', '/primaryConsumption': 'PrimaryConsumption',
              '/reconstruction': 'Reconstruction', '/reconstruction/preview': 'Reconstruction', '/reports': 'Report',
              '/reports/{reportId}': 'Report', '/reports/occurrences': 'Report', '/reports/notificationTypes': 'Report',
              '/reports/notificationFormats': 'Report', '/reports/notificationTargets': 'Report',
              '/reports/notificationSendAsTypes': 'Report', '/reports/exports/{reportId}': 'Report',
              '/reports/views': 'ReportView', '/reports/views/{viewId}': 'ReportView',
              '/reports/views/{id}': 'ReportView', '/schedule/site/{siteId}': 'Schedule',
              '/schedule/{scheduleId}/device': 'Schedule', '/schedule/{scheduleId}/levels': 'Schedule',
              '/schedule/{scheduleId}/exceptions': 'Schedule', '/schedule': 'Schedule',
              '/schedule/{scheduleId}/ticks/year/{year}/week/{weekNumber}': 'Schedule',
              '/schedule/{scheduleId}': 'Schedule', '/schedule/{scheduleId}/exceptions/{exceptionId}': 'Schedule',
              '/schedule/{scheduleId}/ticks/year/{year}/week/{week}/copy/year/{targetYear}/week/{targetWeek}/{weekCount}': 'Schedule',
              '/sims/{id}': 'Sim', '/sims/providers': 'Sim', '/sims': 'Sim', '/sims/count': 'Sim', '/sites': 'Site',
              '/sites/{siteId}': 'Site', '/sites/{siteId}/users': 'Site', '/sites/{siteId}/user/{userId}': 'Site',
              '/sites/account': 'Site', '/sources': 'Source', '/sources/{sourceId}': 'Source',
              '/sources/{sourceId}/user/{userId}': 'Source', '/sources/site': 'Source', '/sources/account': 'Source',
              '/sources/{sourceId}/dataQuality/{historyId}': 'SourceDataQuality',
              '/sources/{sourceId}/dataQuality': 'SourceDataQuality', '/sources/{sourceId}/history': 'SourceHistory',
              '/sources/{sourceId}/indexes/{variableId}': 'SourceIndex',
              '/sources/{sourceId}/indexes/{variableId}/history': 'SourceIndex',
              '/sources/{sourceId}/notes': 'SourceNote', '/sources/{sourceId}/notes/{noteId}': 'SourceNote',
              '/sources/views': 'SourceView', '/sources/views/{viewId}': 'SourceView',
              '/sources/views/{id}': 'SourceView', '/storage': 'Storage', '/storage/tags': 'Storage',
              '/storage/{id}': 'Storage', '/storage/totalUsage': 'Storage', '/storage/file': 'Storage',
              '/storage/exportTemplates': 'Storage', '/storage/canupload/{fileSize}': 'Storage', '/tags': 'Tag',
              '/user/info': 'User', '/user/roles': 'User', '/user/features': 'User', '/user/info/{id}': 'User',
              '/user/role/{id}': 'User', '/user/adminUsers': 'User', '/user/claim/{id}': 'User',
              '/user/rolemapping': 'User', '/user/usermapping': 'User', '/user/getUnitsPreference': 'User',
              '/user/canAccessToSite/{siteId}': 'User', '/user/canAccessToGroup/{groupId}': 'User',
              '/user/canAccessToSource/{sourceId}': 'User', '/user/lock': 'User', '/user/save': 'User',
              '/user/create': 'User', '/user/delete': 'User', '/user/remove': 'User', '/user/password': 'User',
              '/user/saveUser': 'User', '/user/claims/add': 'User', '/user/roles/save': 'User',
              '/user/claims/edit': 'User', '/user/claims/remove': 'User', '/user/isEmailUnique': 'User',
              '/user/saveUnitsPreference': 'User', '/user/resetPassword/{userId}': 'User', '/user/users': 'User',
              '/account/users': 'UserAccount', '/account/features': 'UserAccount',
              '/account/usermapping': 'UserAccount', '/account/secondaryAccesses': 'UserAccount',
              '/account/usermapping/users': 'UserAccount', '/account/user/claim/{userId}': 'UserAccount',
              '/account/usersForAccount/{id}': 'UserAccount', '/account/user/{userId}/features': 'UserAccount',
              '/account': 'UserAccount', '/account/user/{userId}/secondaryAccesses': 'UserAccount',
              '/account/user/{userId}': 'UserAccount', '/account/user/claims/edit': 'UserAccount',
              '/account/user/claims/add': 'UserAccount', '/account/user/{userId}/claims/add': 'UserAccount',
              '/account/user/{userId}/claims/remove': 'UserAccount', '/account/user/create': 'UserAccount',
              '/account/user/{userId}/lock': 'UserAccount', '/account/user/{userId}/resetpassword': 'UserAccount',
              '/account/user/claims/remove': 'UserAccount', '/variables': 'Variable',
              '/variables/periodTypes': 'Variable', '/variables/types': 'Variable',
              '/variables/source/{sourceId}': 'Variable', '/sources/{sourceId}/variables/{variableId}': 'Variable',
              '/variables/types/energytype/{energyTypeId}': 'Variable',
              '/variables/types/{variableTypeId}/energytype/{energyTypeId}': 'Variable',
              '/sources/{sourceId}/variables/{variableId}/calculated/evaluate': 'Variable',
              '/sources/{sourceId}/variables/{variableId}/calculated/validate': 'Variable',
              '/sources/{sourceId}/variables/{variableId}/calculated/sampleData': 'Variable',
              '/account/webhooks/test/{id}': 'Webhook', '/account/webhooks/{id}/history': 'Webhook',
              '/account/webhooks': 'Webhook', '/account/webhooks/{id}': 'Webhook', '/account/webhooks/test': 'Webhook'}
